# Transactionism

## I will profiter

One of the words that's stuck out to me learning French is the verb _profiter_, or _to profit_.
The direct translation is easy - English and French have substantial shared lineage, and this is a word that's unchanged between the two.
The usage and connatations of the word between the two languages does differ, however, and I'd like to explore the many senses of the word(s) for spell.

In English, 'to profit' is more often than not associated with financial or economic contexts.
If one profits from something, they've made money from it, they've got out more than they put in, they've made a worthwhile exchange.
It is generally used in discussions of wealth, ventures, or commercially applied in business.

In French, _profiter_ means the same thing, but has a much weaker financial connotiation.
Rather, it is associated with personal gain in terms of character growth, positive experiences, improved well-being.
For example, « profite bien de tes vacances » directly translates to "profit well of your holidays", but the meaning is closer to "enjoy your holidays".

In English, we are unlikely to talk of profiting from a holiday, or of a positive personal experience, although it makes perfect grammatical sense.
We'd understand someone's use of the word in this sense, though we'd think it an odd turn of phrase.
I think there is something of a knife-edge here, an unstable equilibrium where the same concept resolves to fundamentally different meanings depending on one's own native culture and experience.

What I want to call 'transactionalisation' is the conflation or confusing of these two divergent meanings.
It is easy to think that we are taking a decision that increases our overall utility, when in fact all we are doing is saving time.
I'd like to talk a bit about spending and wasting time, and how the difference between the two is much less clear-cut than we might often think.

## What does it mean to profit?

A well-worn idiom in English is that time is money.
This makes perfect sense in a commercial setting: our economonic systems prize cost-efficiency and reward those that make the most with the least.
This is also true in biology; natural selection optimises and specialises organisms to be the best in their niche, and everything else is made extinct.
In the case of the individual, we could apply the same calculus.
Our lives each have a finite budget of time available, so it follows that we should optimise how to spend it in order to gain the most utility, whatever that may mean for us each individually.

This is the value proposition put forward by industries like match-making (Hinge), ready-made food delivery (HelloFresh), or educational course providers (Udemy).
Generally, they provide a means by which to do something one could already do, but with a much reduced time investment.
There's evidently demand for these industries, and undoubtedly they provide a service that's valued by some segment of the population, so I won't tilt against windmill decrying their existence here.
However, I think there's cause for concern with such time-optimisation.

Take strategies for meeting people to date, for example.
If I use a match-making service, I indicate preference towards some individuals, while they do the same to me and others, and some algorithm tries to match us up with people it thinks we'll like.
If a match is made, we talk, and can arrange to meet up, and from there, perhaps on to form whatever kind of relationship it is we are looking for.
This is straightforward and convenient.

If instead I rely on meeting people by chance, I have to regularly encounter situations in which I am likely to meet people.
I have to additionally hope that those people will be the kinds of people I am likely to get along with, and that they are also looking to meet new people.
I also have to be someone that is interesting enough out of a chance encounter that someone I meet would like to see me again.
This is deeply complex, massively daunting, and extremely time-consuming.

If we focus on that aspect of chance in the second strategy, it would seem that dating apps are a much better time investment.
Instead of having to figure out things to do, places to go, and presumably spending money to enable the ordeal, I can instead look for a date while in the midst of the rest of my daily life.
I know that the poeple I see there are interested, broadly speaking, in the same thing as me, and can precisely tune my preferences.
It should work out that not only do I spend less time looking for someone, I also find someone that is likely to closely match myself.
Therefore, using a dating application is a much better use of my time!

Or so it would seem.
I think that, contrary to their apparent goal of bringing people together, it's actually quite likely that dating applications are contributing to pushing them apart.
Let me explain.

First, it should be re-iterated that when you're using a dating app, you are not looking at people.
You are looking at people's *profiles*, which I would argue are actually a very poor indication of what the person behind it is like.
It's well-documented that people don't represent themselves honestly on online platforms, and it would be unreasonable to expect them to.
It's also filtered through whatever particular platform you happen to be using, which further limits any genuine self-expression someone can display.

We also should consider our own biases; applications will allow you to set an age range, political preferences, drink and drug tolerance, religious view, et cetera.
In plenty of cases this is perfectly reasonable, but isn't it also easy to see how this enables a user to set their own expectations unreasonably high?

Finally, let's examine the time spent on the application itself.
It's true that, like any number of modern mobile apps, the minimumm time investement is very low.
You can set up a profile in minutes, and from there you can view profiles on the train, in the coffee queue, or taking a dump.
Because it's so easy to do, it means that *you do it easily*.

Most of us are already chronically phone users, and I absolutely count myself among them. 
It's devastatingly easy to fall into a habit, and once a habit is dug in it will begin to effect how you think.
What started as a canny time saving becomes a time sink in itself. 
Not only that, but it also expends energy making what are ultimately low-value decisions, culminating in decision fatigue.
A decision-fatigued person no longer has the energy to make energy choices, and so will but succumb to their habits more.

Let's re-examine the things we have to do to meet people by chance: encounter new situations with new pople in them, go somewhere that I'd like to be, and be approachable and charming.
Put this way, don't these maybe sound like goals on their own?

We could directly pursue those other goals, which don't require any chance.
We each know where we could go to encounter new situations, and if we don't, we could probably find out if we applied ourselves to the problem.
We each have our insecurities, and especially after an isolating pandemic likely need the face-to-face practice of being where people are anyway.

I think that directly pursuing a goal like "get into a relationship" is something of a façade.
It inherently depends on another person and the circumstances under which we find ourselves together.
That aspect of chance is what makes dating so difficult, but also what makes it so rewarding.

## Reclaiming time

I have a lot of goals and ambitions I'd like to achieve, but it's rare that I work towards any of them directly on a critical path.
I prefer to find ways to achieve those goals which I can reliably make progress towards easily.
Things which are hard take a lot of work, which means a lot of time.
For me, I think this means that more importantly than finding ways to work hard, is finding ways not to give up.
If one can lay the foundation of habit, of not giving up, the hard work is easier to come by later on.

One could argue quite reasonably that the slow path is wasting time, but I think that's a matter of framing.
Any time you enjoyed, and look back on after as having enjoyed, surely wasn't wasted.
I could surely have achieved more things, more quickly, had I taken a faster approach to language.
I could have spent more time learning, or working towards some other goal, had I opted for a faster relationship with food.
But if I'd taken that optimised path, I might have missed out on enjoying the thing in the first place, and if I'm not enjoying it, I can only wonder if I'm missing the point.

---

I didn't reference anything directly, but there are a few books I've been thinking about which motivated this point of view. They are:

* [You Are Not A Gadget](https://www.goodreads.com/en/book/show/6683549-you-are-not-a-gadget)
* [Dataism](https://www.goodreads.com/book/show/31138556-homo-deus)
* [Zen and The Art of Motorcycle Maintenance](https://www.goodreads.com/book/show/19438058-zen-and-the-art-of-motorcycle-maintenance)
